% % % test unsupervised mode of Deblender tool with GSE19830 dataset. It has 33 mixed
% % % samples including 3 tissues. In this example, all probes of the dataset are included except the control probes starting with AFFX-. 
% % % the input is the mixed expression data 'mixed_data', the probe names 'mixed_genes'. 
% % % the output is the proportion matrix 'A_estimated'
% % % the ground truth proportion matrix is 'A_real'


load('GSE11058_all_plus_processed.mat')

% % run mixture proportion estimation with Stage I
% % How to set these cutoffs check the manuscript.


K_source=4; low_cutoff=0.1; upper_cutoff=0.1; coef_var=0.1;clust_algo=1; log_option=1;algo_solver=1;call_NMF=0;limit_cent_neigh=0;

[A_estimated , ~, ~, ~]  = calc_A_unsupervised(mixed_genes, mixed_data, mixed_data, K_source, low_cutoff, upper_cutoff, coef_var, clust_algo, log_option, algo_solver, call_NMF, limit_cent_neigh);


% % try all possible order configurations relative to ground truth in order
% % to find the one with maximum correlation
v=perms((1:1:K_source));
index_corr=zeros(size(v,1),1);
A_real_vectorized=reshape(A,size(A,1)*size(A,2),1);     
for i=1:size(v,1)
        temp_A_est=[A_estimated(:,v(i,1)) A_estimated(:,v(i,2)) A_estimated(:,v(i,3)) A_estimated(:,v(i,4))];
        temp_A_est_vectorized=reshape(temp_A_est,size(temp_A_est,1)*size(temp_A_est,2),1);
        index_corr(i,1)=corr(temp_A_est_vectorized,A_real_vectorized);
end
[p, ~]=find(index_corr==max(index_corr));


% % define the best configuration for proportions and plot against ground
% truth
A_estimated=[A_estimated(:,v(p,1)) A_estimated(:,v(p,2)) A_estimated(:,v(p,3)) A_estimated(:,v(p,4))];

new=reshape(A_estimated,size(A_estimated,1)*size(A_estimated,2),1); 
corr(new,A_real_vectorized)
RMSE=sqrt( sum( (new(:)-A_real_vectorized(:)).^2) / numel(A_real_vectorized) ); 

figure('Name', 'Mixture proportions')
subplot(2,2,1); scatter(A_estimated(:,1),A(:,1),'b','filled');hold on;plot((0:0.000001:1),(0:0.000001:1)); title('Jurkat')
subplot(2,2,2); scatter(A_estimated(:,2),A(:,2),'b','filled');hold on;plot((0:0.000001:1),(0:0.000001:1)); title('IM-9')
subplot(2,2,3); scatter(A_estimated(:,3),A(:,3),'b','filled');hold on;plot((0:0.000001:1),(0:0.000001:1)); title('Raji')
subplot(2,2,4); scatter(A_estimated(:,4),A(:,4),'b','filled');hold on;plot((0:0.000001:1),(0:0.000001:1)); title('THP-1')

gplot(A_estimated, A);

fprintf('RMSE \n',RMSE);
fprintf('The correlation for Jurkat is %i.\n',corr(A_estimated(:,1),A(:,1)))
fprintf('The correlation for IM-9 is %i.\n',corr(A_estimated(:,2),A(:,2)))
fprintf('The correlation for Raji is %i.\n',corr(A_estimated(:,3),A(:,3)))
fprintf('The correlation for THP-1 is %i.\n',corr(A_estimated(:,4),A(:,4)))

